@@ -19,6 +19,7 @@ has_dialog = 0
 #Activate one line of scripting. See scripting.txt for details.
 #returns either 0<= (failure), >0 (success),
 #or "end" (end script).
+#x and y are absolute values.
 def activate_line(x, y, z, command, tile_type=""):
 
 	global has_dialog
@@ -63,7 +64,7 @@ def activate_line(x, y, z, command, tile_type=""):
 
 	elif switch == "delpix": #remove a picture from the tile.
 		try:
-			g.maps[z].field[y + g.ygrid][x + g.xgrid].del_pix(
+			g.maps[z].field[y][x].del_pix(
 				g.tiles[command.split(None, 2)[1]])
 			main.refreshmap()
 			return_num = 1
@@ -77,7 +78,7 @@ def activate_line(x, y, z, command, tile_type=""):
 	elif switch == "die":  #process endgame.txt script
 		g.hp = -1
 		for line in g.endgame_act:
-			activate_line(g.xgrid, g.ygrid, g.zgrid, line)
+			activate_line(x, y, z, line)
 		return_num = "end"
 
 	elif switch == "end":  #end the script
