@@ -49,7 +49,7 @@ def refresh():
 	canvas_mon_hp.create_rectangle(0, 0, temp_width,
 		g.hpbar_width/6, fill="#05BB05", tags="show_mon_hp")
 
-	main.recalc_stats()
+	main.recalc_stats(1)
 
 	#clear and rebuild listbox_item
 	listbox_item.delete(0, END)
@@ -213,12 +213,11 @@ def useitem():
 	refresh()
 
 	#replace the cursor
-	if (listbox_item.size() == 0): return 0
-
-	listbox_item.selection_set(item_num[0])
-	if (len(listbox_item.curselection()) == 0): #last item
-		listbox_item.selection_set(item_num[0] - 1)
-
+	if (listbox_item.size() != 0):
+		listbox_item.selection_set(item_num[0])
+		if (len(listbox_item.curselection()) == 0): #last item
+			listbox_item.selection_set(item_num[0] - 1)
+	refresh_buttons()
 
 
 def useskill():
@@ -250,11 +249,12 @@ def useskill():
 	if g.skill[skill_index][1] == 0: #rage
 		main.print_message("You fly into a rage.")
 		#increase attack ability
-		g.adj_attack += (1 + int(g.level)/2)
+		g.adj_attack += (1 + int(g.level)/4)
+		main.attack.set(g.adj_attack)
 		attack_player()
 
 	elif g.skill[skill_index][1] == 1: #Sneak away
-		if g.die_roll(1, 10 + int(g.level)) > 5:
+		if g.die_roll(1, 10 + int(g.level)) > 4:
 			main.print_message("You coward! You ran away from the " +
 				monster.monsters[mon_index].name + ".")
 			window_battle.destroy()
@@ -273,7 +273,7 @@ def useskill():
 		if g.cur_mon_hp > 0:
 			attack_player()
 	elif g.skill[skill_index][1] == 3: #Dismember
-		damage = g.adj_attack + 2
+		damage = g.adj_attack * 2
 		main.print_message("You hit the " + monster.monsters[mon_index].name +
 			" for " + str(damage) + " damage.")
 		g.cur_mon_hp = g.cur_mon_hp - damage
@@ -285,14 +285,13 @@ def useskill():
 			attack_player()
 
 	refresh()
-	refresh_buttons()
 
 	#replace the cursor
-	if (listbox_skill.size() == 0): return 0
-
-	listbox_skill.selection_set(skill_num[0])
-	if (len(listbox_skill.curselection()) == 0): #last skill
-		listbox_skill.selection_set(END)
+	if (listbox_skill.size() != 0):
+		listbox_skill.selection_set(skill_num[0])
+		if (len(listbox_skill.curselection()) == 0): #last skill
+			listbox_skill.selection_set(END)
+	refresh_buttons()
 
 
 
