@@ -5,7 +5,7 @@
 #This file contains everything that needs to be accessed by most or all files.
 
 
-#Dragon Hunt 3.37. Released under the GPL. Copyright 2004
+#Dragon Hunt 3.38. Released under the GPL. Copyright 2004
 #(Note to self: when changing version, change variables.txt, README.txt,
 # and setup.py.)
 
@@ -458,14 +458,9 @@ def die_roll(dice, sides, modfy = 0):
 	return sum
 
 
-#Returns the symbol of the given tile. X and Y are relative
-#to the location of the player.
+#Returns the symbol of the given tile. X and Y are absolute coords.
 def checklocation(x, y):
 
-	#transform from relative to absolute coordinates
-	x = xgrid + x
-	y = ygrid + y
-
 	#Assume that all off-map areas are rock.
 	if x < 0 or y < 0:
 		return 'a'
@@ -478,9 +473,6 @@ def checklocation(x, y):
 
 #like checklocation, but just returns 0 (rock) or 1 (grass)
 def iswalkable(x, y):
-	#transform from relative to absolute coordinates
-	x = xgrid + x
-	y = ygrid + y
 
 	#Assume that all off-map areas are rock.
 	if x < 0 or y < 0:
