@@ -156,11 +156,11 @@ def inv_show_yesno(line=""):
 	canvas_inv2.create_image(canvas_width/2,
 		canvas_height, image=yes_button, anchor="sw", tags="yes")
 	#bindings
-	main.window_main.bind("<Up>", change_yesno_sel)
-	main.window_main.bind("<Right>", change_yesno_sel)
-	main.window_main.bind("<Left>", change_yesno_sel)
-	main.window_main.bind("<Down>", change_yesno_sel)
-	main.window_main.bind("<Return>", activate_yesno)
+	main.window_main.bind(g.binding_up, change_yesno_sel)
+	main.window_main.bind(g.binding_right, change_yesno_sel)
+	main.window_main.bind(g.binding_left, change_yesno_sel)
+	main.window_main.bind(g.binding_down, change_yesno_sel)
+	main.window_main.bind(g.binding_action, activate_yesno)
 	canvas_inv2.tag_bind("no", "<Enter>", change_yesno_to_no)
 	canvas_inv2.tag_bind("yes", "<Enter>", change_yesno_to_yes)
 	canvas_inv2.tag_bind("no", "<Button-1>", activate_yesno)
@@ -225,7 +225,7 @@ def use_item():
 		#heal the player, delete the item
 		g.hp=g.hp + item.item[item_value].quality
 		item.drop_inv_item(curr_item)
-		if g.hp >= g.maxhp: g.hp = g.maxhp
+		if g.hp >= g.adj_maxhp: g.hp = g.adj_maxhp
 
 	refresh_inv()
 
@@ -648,13 +648,13 @@ def init_window_inv():
 #bind the keys. Called upon window creation and return from a yes/no box
 def bind_keys():
 	canvas_inv.bind("<ButtonRelease-1>",  mouse_sel_inv)
-	main.window_main.bind("<Escape>", key_handler_esc)
-	main.window_main.bind("<Return>", key_handler_return)
-	main.window_main.bind("<Up>", key_handler_up)
-	main.window_main.bind("<Down>", key_handler_down)
-	main.window_main.bind("<Left>", key_handler_left)
-	main.window_main.bind("<Right>", key_handler_right)
-	main.window_main.bind("<Prior>", key_handler_pgup)
-	main.window_main.bind("<Next>", key_handler_pgdn)
+	main.window_main.bind(g.binding_cancel, key_handler_esc)
+	main.window_main.bind(g.binding_action, key_handler_return)
+	main.window_main.bind(g.binding_up, key_handler_up)
+	main.window_main.bind(g.binding_down, key_handler_down)
+	main.window_main.bind(g.binding_left, key_handler_left)
+	main.window_main.bind(g.binding_right, key_handler_right)
+	main.window_main.bind(g.binding_inv_left, key_handler_pgup)
+	main.window_main.bind(g.binding_inv_right, key_handler_pgdn)
 	canvas_buttons.bind("<ButtonRelease-1>", mouse_handler_click)
 	canvas_buttons.bind("<Motion>", mouse_handler_move)
