@@ -34,7 +34,7 @@ width = 20
 status_box_height =6
 tilesize = 32
 
-#division is nasty. Only do it once.
+#division is nasty. Only do it once. Used for centering items on the player.
 half_mapx = mapsizex/2
 half_mapy = mapsizey/2
 
@@ -110,28 +110,28 @@ def close_window(event=0):
 				pass
 
 
-#Activate any scripting associated with a tile. X and Y are relative
-#to the location of the player.
-#assumes scripting stored in maps[zgrid].field[y][x].actions[]
+#Activate any scripting associated with a tile. X and Y are absolute coords.
+#Assumes scripting stored in maps[zgrid].field[y][x].actions[]
 def activate_scripting(x, y, z):
 	return_num = 0
-	temp_xgrid = x + g.xgrid
-	temp_ygrid = y + g.ygrid
 	temp_zgrid = z
 
-	for itemname in g.maps[g.zgrid].field[temp_ygrid][temp_xgrid].items:
+	itemnum = 0
+	while itemnum < len(g.maps[g.zgrid].field[y][x].items):
+		itemname = g.maps[g.zgrid].field[y][x].items[itemnum]
 		if action.activate_line(x, y, z, "find \"" + itemname + "\" a"):
-			g.maps[g.zgrid].del_item(itemname, temp_xgrid, temp_ygrid)
-			refresh_tile(half_mapx+x, half_mapy+y)
+			g.maps[g.zgrid].del_item(itemname, x, y)
+			refresh_tile(x, y)
+		else: itemnum += 1
 
 	#if there are no actions, leave immediately
-	if len(g.maps[temp_zgrid].field[y+g.ygrid][x+g.xgrid].actions) == 0: return
+	if len(g.maps[temp_zgrid].field[y][x].actions) == 0: return
 
 	i = 0
 	#go through all action lines.
-	while i < len(g.maps[temp_zgrid].field[temp_ygrid][temp_xgrid].actions):
+	while i < len(g.maps[temp_zgrid].field[y][x].actions):
 		temp = action.activate_line(x, y, z,
-			g.maps[temp_zgrid].field[temp_ygrid][temp_xgrid].actions[i])
+			g.maps[temp_zgrid].field[y][x].actions[i])
 		if temp == "end": break
 		if dead_yet() == 1:
 			break
@@ -141,23 +141,21 @@ def activate_scripting(x, y, z):
 #redraws the main map. Call after moving.
 def refreshmap():
 	#redraw the tiles
-#	canvas_map.delete(ALL)
 	for x in range(mapsizex):
 		for y in range(mapsizey):
-			refresh_tile(x, y)
+			refresh_tile(g.xgrid - half_mapx + x, g.ygrid - half_mapy + y)
 
 	refreshhero()
 	recalc_stats()
 
-#given x and y relative to the upper-left corner of the visible map,
-# refresh the given tile.
+#given x and y (absolute coods.) refresh the given tile.
 def refresh_tile(x, y):
-	search_for = str(g.xgrid+x-half_mapx)+"."+ str(g.ygrid+y-half_mapy)
+	search_for = str(x)+"."+str(y)
 	canvas_map.delete(search_for)
-	for picture in findtile(x-half_mapx, y-half_mapy):
-		canvas_map.create_image(x*g.tilesize, y*g.tilesize, anchor=NW,
-		image=picture, tags=str(g.xgrid+x-half_mapx)+"."+
-		str(g.ygrid+y-half_mapy))
+	for picture in findtile(x, y):
+		canvas_map.create_image((x-g.xgrid + half_mapx)*g.tilesize,
+		(y-g.ygrid + half_mapy)*g.tilesize, anchor=NW,
+		image=picture, tags=str(x)+"."+str(y))
 
 #refreshs the hero; faster than refreshing the whole map.
 def refreshhero():
@@ -180,25 +178,30 @@ def process_onload():
 				if temp == "end": break
 				if dead_yet() == 1: break
 
-#recalculate and display stats
-def recalc_stats():
-	#adjust attack and defense based on equipment.
-	g.adj_attack = int(g.attack)
-	if g.item.equip[0] != -1:
-		g.adj_attack = g.adj_attack + g.item.item[g.item.equip[0]].quality
-	for i in range(6):
-		if g.item.equip[i] != -1:
-			g.adj_attack = g.adj_attack + g.item.item[g.item.equip[i]].attack_bonus
-	attack.set(g.adj_attack)
+#recalculate and display stats. leave_att_def_alone is for calling from a
+#battle.
+def recalc_stats(leave_att_def_alone = 0):
+	if leave_att_def_alone == 0:
+		#adjust attack and defense based on equipment.
+		g.adj_attack = int(g.attack)
+		if g.item.equip[0] != -1:
+			g.adj_attack = g.adj_attack + g.item.item[g.item.equip[0]].quality
+		for i in range(6):
+			if g.item.equip[i] != -1:
+				g.adj_attack = g.adj_attack + \
+							g.item.item[g.item.equip[i]].attack_bonus
+		attack.set(g.adj_attack)
 
-	g.adj_defense = int(g.defense)
-	for i in range(1, 6):
-		if g.item.equip[i] != -1:
-			g.adj_defense = g.adj_defense + g.item.item[g.item.equip[i]].quality
-	for i in range(6):
-		if g.item.equip[i] != -1:
-			g.adj_defense = g.adj_defense + g.item.item[g.item.equip[i]].defense_bonus
-	defense.set(g.adj_defense)
+		g.adj_defense = int(g.defense)
+		for i in range(1, 6):
+			if g.item.equip[i] != -1:
+				g.adj_defense = g.adj_defense + \
+							g.item.item[g.item.equip[i]].quality
+		for i in range(6):
+			if g.item.equip[i] != -1:
+				g.adj_defense = g.adj_defense + \
+							g.item.item[g.item.equip[i]].defense_bonus
+		defense.set(g.adj_defense)
 
 	gold.set(g.gold)
 	exp.set(g.exp)
@@ -232,20 +235,17 @@ def recalc_stats():
 
 
 #Return an array of pictures that the given tile should display.
-#x and y are relative to the player.
+#x and y are absolute coords.
 def findtile(x, y):
-	#g.maps[g.zgrid].field[][].pix)
-	#transform from relative to absolute coordinates
-	x = g.xgrid + x
-	y = g.ygrid + y
 
 	returnpix = []
-	#Assume that all off-map areas are rock.
-	if x < 0 or y < 0:
-		returnpix.append(g.maps[g.zgrid].field[0][0].pix)
-		return returnpix
+	#If dealing with an off-map area, grab the nearest known tile.
+	if x < 0: x = 0
+	if y < 0: y = 0
+	if y >= len(g.maps[g.zgrid].field): y = len(g.maps[g.zgrid].field) -1
+	if x >= len(g.maps[g.zgrid].field[y]): x = len(g.maps[g.zgrid].field[y]) -1
 	try:
-		#this will fail when looking too far right or down
+		#This should not (normally) fail.
 		returnpix.append(g.maps[g.zgrid].field[y][x].pix)
 		for picture in g.maps[g.zgrid].field[y][x].addpix:
 			returnpix.append(picture)
@@ -270,15 +270,17 @@ def findtile(x, y):
 #requires the change in xy coordinates. Called with move_north and the like.
 def move_hero(x, y):
 	try:
+		tempy = g.ygrid + y
+		tempx = g.xgrid + x
 		#check for either the main window not existing, or a current dialog
 		if window_main.state() != "normal" or action.has_dialog == 1:
 			return
 		#tempclock = clock()
 		#check for any objects of interest. Called before moving, in case
 		#the scripting changes the walkable status.
-		activate_scripting(x, y, g.zgrid)
+		activate_scripting(tempx, tempy, g.zgrid)
 
-		if g.iswalkable(x, y):
+		if g.iswalkable(tempx, tempy):
 			if g.allow_move == 1:
 				g.xgrid=g.xgrid + x
 				g.ygrid=g.ygrid + y
@@ -305,16 +307,16 @@ def move_hero(x, y):
 				g.allow_move = 1
 				if y == -1:
 					for tilenum in range(mapsizex):
-						refresh_tile(tilenum, 0)
+						refresh_tile(g.xgrid-half_mapx+tilenum, g.ygrid-half_mapy)
 				if y ==  1:
 					for tilenum in range(mapsizex):
-						refresh_tile(tilenum, mapsizey-1)
+						refresh_tile(g.xgrid-half_mapx+tilenum, g.ygrid+half_mapy)
 				if x == -1:
 					for tilenum in range(mapsizey):
-						refresh_tile(0, tilenum)
+						refresh_tile(g.xgrid-half_mapx, g.ygrid-half_mapy+tilenum)
 				if x ==  1:
 					for tilenum in range(mapsizey):
-						refresh_tile(mapsizex-1, tilenum)
+						refresh_tile(g.xgrid+half_mapx, g.ygrid-half_mapy+tilenum)
 
 		else:
 			if y == -1: g.cur_hero = "people/hero_n.png"
@@ -681,6 +683,7 @@ def bind_keys():
 
 #handles mouse clicks on the main tile canvas.
 def mouse_handler(event=0):
+	#set variables, based on the shape of the main window. (tall or wide)
 	if mapsizex > mapsizey:
 		mapsz = mapsizey*g.tilesize
 		mapstartx = (mapsizex*g.tilesize - mapsz)/2
@@ -689,6 +692,8 @@ def mouse_handler(event=0):
 		mapsz = mapsizex*g.tilesize
 		mapstartx = 0
 		mapstarty = (mapsizey*g.tilesize - mapsz)/2
+	#This basically divides the screen along diagonals, then finds the
+	#current quadrent of the mouse.
 	if (event.x - mapstartx < event.y - mapstarty): #south or west
 		if (event.x + event.y > mapstartx+mapstarty+mapsz): move_south()
 		else: move_west()
