@@ -390,15 +390,15 @@ def init_window_shop(store_type_input):
 	#bindings
 	canvas_shop.bind("<ButtonRelease-1>", mouse_sel_shop)
 	canvas_inv.bind("<ButtonRelease-1>",  mouse_sel_inv)
-	main.window_main.bind("<Escape>", key_handler_esc)
-	main.window_main.bind("<Left>", key_handler_left)
-	main.window_main.bind("<Right>", key_handler_right)
-	main.window_main.bind("<Up>", key_handler_up)
-	main.window_main.bind("<Down>", key_handler_down)
-	main.window_main.bind("<Return>", key_handler_return)
-	main.window_main.bind("i", key_handler)
-	main.window_main.bind("s", key_handler)
-	main.window_main.bind("q", key_handler)
+	main.window_main.bind(g.binding_cancel, key_handler_esc)
+	main.window_main.bind(g.binding_left, key_handler_left)
+	main.window_main.bind(g.binding_right, key_handler_right)
+	main.window_main.bind(g.binding_up, key_handler_up)
+	main.window_main.bind(g.binding_down, key_handler_down)
+	main.window_main.bind(g.binding_action, key_handler_return)
+	main.window_main.bind(g.binding_inv, key_handler)
+	main.window_main.bind(g.binding_save, key_handler)
+	main.window_main.bind(g.binding_quit, key_handler)
 
 	show_details()
 	window_shop.master.wait_window(window_shop)
